@@ -20,6 +20,7 @@ $values->set_y(2, 7, undef) or warn $data->error;
 
 my @names = qw/sample14 sample14-h/;
 
+my $path = $ENV{GDGRAPH_SAMPLES_PATH} ? $ENV{GDGRAPH_SAMPLES_PATH} : '';
 for my $my_graph (GD::Graph::bars->new(600,400),
                   GD::Graph::hbars->new(600,400))
 {
@@ -49,7 +50,7 @@ for my $my_graph (GD::Graph::bars->new(600,400),
 
 	bar_spacing         => 1,
 
-	logo                => 'logo.' . GD::Graph->export_format,
+	logo                => "${path}logo." . GD::Graph->export_format,
 	logo_position       => 'BR',
 
 	transparent         => 0,
@@ -88,3 +89,5 @@ for my $my_graph (GD::Graph::bars->new(600,400),
     $my_graph->plot($data) or die $my_graph->error;
     save_chart($my_graph, $name);
 }
+
+1;
